--[[ 
	Developed by: Tamaroth @ Quel'Thalas EU
	Simple addon that stop displaying cerain loot from your chat, no more badges spam during boss loot.
	If item is on ignore loot list, it will be shown only if you loot it.
]]--

-- default values
local BB_DefIgnoredChannels = {
	["SAY"] = false,
	["PARTY"] = false,
	["RAID"] = false,
	["GUILD"] = false,
	["CHANNEL"] = false,
	["LOOT"] = true,
}
local BB_DefIgnoredLoot = {
	{ ["item"] = "Badge of Justice" },
	{ ["item"] = "Emblem of Valor" },
	{ ["item"] = "Emblem of Heroism" }, 
	{ ["item"] = "Stone Keeper's Shard" },
	{ ["item"] = "Mark of Honor" },
	{ ["item"] = "Emblem of Conquest" },
	{ ["item"] = "Qiraji Lord's Insignia" }, 
	{ ["item"] = "Wintergrasp Mark of Honor" },
	}

function BB_OnLoad()
	-- default values for new users, badges will always by ignored
	if not BB_IgnoredLoot then
		BB_IgnoredLoot = BB_DefIgnoredLoot
		DEFAULT_CHAT_FRAME:AddMessage("Ignore item list has been initialized")
	end
	-- start as enabled addon
	if not BB_Enabled then
		BB_Enabled = true
	end
	if BB_Enabled then
		DEFAULT_CHAT_FRAME:AddMessage("BadgeBlocker is enabled!")
	end
	-- by default ignore all loot msgs
	if (not BB_IgnoredChannels) then
		BB_IgnoredChannels = BB_DefIgnoredChannels
	end
	
	SLASH_BBLOCK1 = "/bblock"
	SLASH_BBLOCK2 = "/badgeblock"
	SlashCmdList["BBLOCK"] = BB_CheckSettings

	-- chat filters
	ChatFrame_AddMessageEventFilter("CHAT_MSG_LOOT", BB_ChatFilter)
	
	DEFAULT_CHAT_FRAME:AddMessage("BadgeBlocker Loaded! Use /bblock to see more options")
end

function BB_CheckSettings(args)
	local commands = {}
    
	string.gsub(args, "%S+", function(word) table.insert(commands, word) end)

	if not commands[1] then
		BB_HelpMsg()
	elseif commands[1] == "enable" then
		BB_Enabled = not BB_Enabled
		if BB_Enabled then
			DEFAULT_CHAT_FRAME:AddMessage("BadgeBlocker is enabled!")
		else
			DEFAULT_CHAT_FRAME:AddMessage("BadgeBlocker is disabled!")
		end
	elseif commands[1] == "add" then
		if commands[2] then
			local _, _, item = string.find(args, "^add (.+)$")
			DEFAULT_CHAT_FRAME:AddMessage("Added "..item.." to ignore list")
			tinsert(BB_IgnoredLoot, 1, { ["item"] = item })
		else
			DEFAULT_CHAT_FRAME:AddMessage("Usage: /bblock add <item>")
		end
	elseif commands[1] == "rem" then
		if (commands[2]) then
			local _, _, item = string.find(args, "^rem (.+)$")
			local found = 0
			if (BB_IgnoredLoot) then
				for k, v in pairs(BB_IgnoredLoot) do
					if (strlower(v["item"]) == strlower(item)) then
						tremove(BB_IgnoredLoot, k)
						DEFAULT_CHAT_FRAME:AddMessage(item.." removed from list")
						found = 1
						break;
					end
				end
			end
			if (found == 0) then
				DEFAULT_CHAT_FRAME:AddMessage(item .. " not found in loot ignore list.")
			end
		else
			DEFAULT_CHAT_FRAME:AddMessage("Usage: /bblock rem <item>")
		end
	elseif commands[1] == "clear" then
		BB_IgnoredLoot = {}
		DEFAULT_CHAT_FRAME:AddMessage("Ignore list has been cleared")
	elseif commands[1] == "list" then
		local num = 0
		if (BB_IgnoredLoot) then
			DEFAULT_CHAT_FRAME:AddMessage("List of ignored items:")
			for k, v in pairs(BB_IgnoredLoot) do
				DEFAULT_CHAT_FRAME:AddMessage(k .. ": " .. v["item"])
				num = num + 1
			end
		end
		if (num == 0) then
			DEFAULT_CHAT_FRAME:AddMessage("No items in loot ignore list.")
		end
	elseif commands[1] == "chan" then
		local chatn = commands[2]
		if (chatn and ((commands[3] == "on") or (commands[3] == "off"))) then 
 			if ((chatn == "SAY") or (chatn == "PARTY") or (chatn == "RAID") or (chatn == "GUILD") or (chatn == "CHANNEL") or (chatn == "LOOT")) then
				if (commands[3] == "on") then
					BB_IgnoredChannels[commands[2]] = true
					ChatFrame_AddMessageEventFilter("CHAT_MSG_"..commands[2], "BB_ChatFilter")
					DEFAULT_CHAT_FRAME:AddMessage("Now ignoring loot from "..commands[2].." source")
				else
					BB_IgnoredChannels[commands[2]] = false
					ChatFrame_RemoveMessageEventFilter("CHAT_MSG_"..commands[2], "BB_ChatFilter")
					DEFAULT_CHAT_FRAME:AddMessage("Stopped ignoring loot from "..commands[2].." source")
				end
			else
				DEFAULT_CHAT_FRAME:AddMessage("Usage: /bblock chan <SAY/PARTY/RAID/GUILD/CHANNEL/LOOT> <on/off>")
			end
		else
			DEFAULT_CHAT_FRAME:AddMessage("Usage: /bblock chan <SAY/PARTY/RAID/GUILD/CHANNEL/LOOT> <on/off>")
		end
    end
end

function BB_HelpMsg()
	DEFAULT_CHAT_FRAME:AddMessage("BadgeBlockers status:")
	if BB_Enabled then
		DEFAULT_CHAT_FRAME:AddMessage("   BadgeBlocker is enabled!")
	else
		DEFAULT_CHAT_FRAME:AddMessage("   BadgeBlocker is disabled!")
	end
	DEFAULT_CHAT_FRAME:AddMessage("/bblock enable - Enable/Disable addon")
	DEFAULT_CHAT_FRAME:AddMessage("/bblock add <item> - Add item to ignore list")
	DEFAULT_CHAT_FRAME:AddMessage("/bblock rem <item> - Remove item from ignore list")
	DEFAULT_CHAT_FRAME:AddMessage("/bblock clear - Clears ignore list")
	DEFAULT_CHAT_FRAME:AddMessage("/bblock list - List current ignore list")
	DEFAULT_CHAT_FRAME:AddMessage("/bblock chan <SAY/PARTY/RAID/GUILD/CHANNEL/LOOT> <on/off> - turn on and off channels to ignore loot")
end

function BB_ChatFilter(self, event, msg, ...)
	local iStart, _, sPlayer, sItem = string.find(msg, "([^%s]+) receive[s]? loot: (.+)%.");
	
	if (iStart) then
		if ((BB_IgnoredLoot) and (sPlayer ~= "You")) then
			for k, v in pairs(BB_IgnoredLoot) do
				local lStart, _, match = string.find(strlower(sItem), strlower(v["item"]));
				if (lStart) then
					return true
				end
			end
		end
	else
		local iStart2, _, sPlayer2, sItem2, _ = string.find(msg, "([^%s]+) create[s]?: (.+)%."); 
		if (iStart2) then
			if ((BB_IgnoredLoot) and (sPlayer2 ~= "You")) then
				for k, v in pairs(BB_IgnoredLoot) do
					local lStart, _, match = string.find(strlower(sItem2), strlower(v["item"]));
					if (lStart) then
						return true
					end
				end
			end
		end
	end
end
